2.0.9 (2024-07-10)
~~~~~~~~~~~~~~~~~~

* [IMP] It does no more depends on os0
* [IMP] Python 3.6 deprecated

2.0.8 (2024-03-26)
~~~~~~~~~~~~~~~~~~

* [IMP] set_workers: no automatic discover for odoo multi
* [IMP] Purged old unused code
* [IMP] New odooctl command

2.0.7 (2024-02-05)
~~~~~~~~~~~~~~~~~~

* [REF] set_workers refactoring

2.0.6 (2023-04-16)
~~~~~~~~~~~~~~~~~~

* [FIX] Import class models.Model

2.0.5 (2023-03-23)
~~~~~~~~~~~~~~~~~~

* [IMP] run_odoo_debug.sh: moved to package wok_code

2.0.4 (2023-01-13)
~~~~~~~~~~~~~~~~~~

* [IMP] run_odoo_debug.sh: test creates log

2.0.3 (2022-11-11)
~~~~~~~~~~~~~~~~~~

* [IMP] odoo_score: implementation of models and fields for Odoo 8-0+ modules

2.0.2 (2022-10-20)
~~~~~~~~~~~~~~~~~~

* [FIX] run_odoo_debug: test function improvements
* [IMP] run_odoo_debug: ODOO_COMMIT_TEST

2.0.1.1 (2022-10-13)
~~~~~~~~~~~~~~~~~~~~

* [IMP] run_odoo_debug: python stub
* [FIX] run_odoo_debug: crash in sime rare cases

2.0.1 (2022-10-12)
~~~~~~~~~~~~~~~~~~~~

* [IMP] stable version

2.0.0.3 (2022-10-05)
~~~~~~~~~~~~~~~~~~~~

* [IMP] run_odoo_debug: test via pycharm
* [FIX] run_odoo_debug: concurrent tests

2.0.0.2 (2022-09-22)
~~~~~~~~~~~~~~~~~~~~

* [IMP] run_odo_debug: test with random rpcport for multiple tests
* [IMP] odoo_shell.py: new actions

2.0.0.1 (2022-09-07)
~~~~~~~~~~~~~~~~~~~~

* [FIX] run_odo_debug with debug
* [IMP] run_odoo_debug: experimental debug via pycharm

2.0.0 (2022-08-10)
~~~~~~~~~~~~~~~~~~

* [REF] Stable version
